==> mailchimp_popup_block-8.x-1.1.tar.gz: mailchimp_popup_block/tests/src/FunctionalJavascript/MailchimpPopupBlockTest.php <==
<?php

namespace Drupal\Tests\mailchimp_popup_block\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * Tests the Mailchimp Popup Block feature functional.
 *
 * @group mailchimp_popup_block
 */
class MailchimpPopupBlockTest extends WebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  public static $modules = [
    'mailchimp_popup_block',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    $this->drupalPlaceBlock('mailchimp_popup_block', [
      'label' => 'Newsletter',
      'description' => 'Intro text for the newsletter, shown before the button.',
      'button_text' => 'Subscribe',
      'mailchimp_baseurl' => 'mc.us19.list-manage.com',
      'mailchimp_uuid' => '9ac5e64aa79c90e8642517d48',
      'mailchimp_lid' => '6de1ea04cb',
    ]);
  }

  /**
   * Tests, that the trigger button opens the Mailchimp Popup.
   */
  public function testTriggerMailchimpPopup() {
    // Visit the frontpage.
    $this->drupalGet('<front>');

    // Click the trigger button.
    $this->assertElementPresent('.mailchimp-popup-block__trigger');
    $this->click('.mailchimp-popup-block__trigger');

    // Check, that the Mailchimp Signup Popup was opened.
    // Temporary disable the checks, because DrupalCI fails to load in
    // the mailchimp popup correctly.
    //$this->getSession()->wait(5000);
    //$this->assertSession()->elementExists('css', '#PopupSignupForm_0');
  }

}

==> mailchimp_popup_block-8.x-1.2.tar.gz: mailchimp_popup_block/tests/src/FunctionalJavascript/MailchimpPopupBlockTest.php <==
<?php

namespace Drupal\Tests\mailchimp_popup_block\FunctionalJavascript;

use Drupal\FunctionalJavascriptTests\WebDriverTestBase;

/**
 * Tests the Mailchimp Popup Block feature functional.
 *
 * @group mailchimp_popup_block
 */
class MailchimpPopupBlockTest extends WebDriverTestBase {

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'mailchimp_popup_block',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->drupalPlaceBlock('mailchimp_popup_block', [
      'label' => 'Newsletter',
      'description' => 'Intro text for the newsletter, shown before the button.',
      'button_text' => 'Subscribe',
      'mailchimp_baseurl' => 'mc.us19.list-manage.com',
      'mailchimp_uuid' => '9ac5e64aa79c90e8642517d48',
      'mailchimp_lid' => '6de1ea04cb',
    ]);
  }

  /**
   * Tests, that the trigger button opens the Mailchimp Popup.
   */
  public function testTriggerMailchimpPopup() {
    // Visit the frontpage.
    $this->drupalGet('<front>');

    // Click the trigger button.
    $this->assertSession()->elementExists('.mailchimp-popup-block__trigger');
    $this->click('.mailchimp-popup-block__trigger');

    // Check, that the Mailchimp Signup Popup was opened.
    // Temporary disable the checks, because DrupalCI fails to load in
    // the mailchimp popup correctly.
    //$this->getSession()->wait(5000);
    //$this->assertSession()->elementExists('css', '#PopupSignupForm_0');
  }

}
